[![Test for icij-common](https://github.com/ICIJ/icij-python/actions/workflows/tests-common.yml/badge.svg)](https://github.com/ICIJ/icij-python/actions/workflows/tests-common.yml)

# Library for utilities commonly used in ICIJ's Python projects

## [`neo4j`](https://neo4j.com/docs/api/python-driver/current/)

- neo4j test utils (useful `pytest` fixtures)
- lightweight migration lib
- handles enterprise support and multiple neo4j DBs

## `logging`

## [`pydantic`](https://github.com/pydantic/pydantic)

- ICIJ's Pydantic models

## `tests`

- common test utils and pytest fixtures
